==> Skellett%201.7.7b.src.zip: Skellett-Legacy-1.7.7b/SkellettGit/src/com/gmail/thelimeglass/Expressions/ExprTeleportCause.java <==
package com.gmail.thelimeglass.Expressions;

import javax.annotation.Nullable;

import org.bukkit.event.Event;
import org.bukkit.event.player.PlayerTeleportEvent;

import com.gmail.thelimeglass.Utils.Config;
import com.gmail.thelimeglass.Utils.PropertyType;
import com.gmail.thelimeglass.Utils.RegisterEnum;
import com.gmail.thelimeglass.Utils.Syntax;

import ch.njol.skript.ScriptLoader;
import ch.njol.skript.Skript;
import ch.njol.skript.lang.Expression;
import ch.njol.skript.lang.SkriptParser;
import ch.njol.skript.lang.util.SimpleExpression;
import ch.njol.util.Kleenean;

@Syntax("[the] teleport cause")
@Config("TeleportCause")
@PropertyType("SIMPLE")
@RegisterEnum("teleportcause")
public class ExprTeleportCause extends SimpleExpression<PlayerTeleportEvent.TeleportCause> {
	
	public Class<? extends PlayerTeleportEvent.TeleportCause> getReturnType() {
		return PlayerTeleportEvent.TeleportCause.class;
	}
	public boolean isSingle() {
		return true;
	}
	public boolean init(Expression<?>[] args, int arg1, Kleenean arg2, SkriptParser.ParseResult arg3) {
		if (!ScriptLoader.isCurrentEvent(PlayerTeleportEvent.class)) {
			Skript.error("You can not use TeleportCause expression in any event but on teleport!");
			return false;
		}
		return true;
	}
	public String toString(@Nullable Event arg0, boolean arg1) {
		return "Teleport cause";
	}
	@Nullable
	protected PlayerTeleportEvent.TeleportCause[] get(Event e) {
		return new PlayerTeleportEvent.TeleportCause[]{((PlayerTeleportEvent)e).getCause()};
	}
}

==> Skellett%201.9.6.src.zip: Skellett-Legacy-1.9.6/SkellettGit/src/com/gmail/thelimeglass/Expressions/ExprTeleportCause.java <==
package com.gmail.thelimeglass.Expressions;

import javax.annotation.Nullable;

import org.bukkit.event.Event;
import org.bukkit.event.player.PlayerTeleportEvent;

import com.gmail.thelimeglass.Utils.Annotations.Config;
import com.gmail.thelimeglass.Utils.Annotations.PropertyType;
import com.gmail.thelimeglass.Utils.Annotations.RegisterEnum;
import com.gmail.thelimeglass.Utils.Annotations.Syntax;

import ch.njol.skript.ScriptLoader;
import ch.njol.skript.Skript;
import ch.njol.skript.lang.Expression;
import ch.njol.skript.lang.ExpressionType;
import ch.njol.skript.lang.SkriptParser;
import ch.njol.skript.lang.util.SimpleExpression;
import ch.njol.util.Kleenean;

@Syntax("[the] teleport cause")
@Config("TeleportCause")
@PropertyType(ExpressionType.SIMPLE)
@RegisterEnum("teleportcause")
public class ExprTeleportCause extends SimpleExpression<PlayerTeleportEvent.TeleportCause> {
	
	public Class<? extends PlayerTeleportEvent.TeleportCause> getReturnType() {
		return PlayerTeleportEvent.TeleportCause.class;
	}
	public boolean isSingle() {
		return true;
	}
	public boolean init(Expression<?>[] args, int arg1, Kleenean arg2, SkriptParser.ParseResult arg3) {
		if (!ScriptLoader.isCurrentEvent(PlayerTeleportEvent.class)) {
			Skript.error("You can not use TeleportCause expression in any event but on teleport!");
			return false;
		}
		return true;
	}
	public String toString(@Nullable Event arg0, boolean arg1) {
		return "Teleport cause";
	}
	@Nullable
	protected PlayerTeleportEvent.TeleportCause[] get(Event e) {
		return new PlayerTeleportEvent.TeleportCause[]{((PlayerTeleportEvent)e).getCause()};
	}
}
